aboutsummaryrefslogtreecommitdiffstats
path: root/target/linux/ar71xx/files/arch/mips/ath79/mach-wnr2000-v3.c
diff options
context:
space:
mode:
authorJohn Crispin <blogic@openwrt.org>2016-01-19 10:16:04 +0000
committerJohn Crispin <blogic@openwrt.org>2016-01-19 10:16:04 +0000
commit778627987088ee195186fbe143b5034ab7350a17 (patch)
tree53d085b302e6cd6d1e8b9ab7ff1cedadd1f5986f /target/linux/ar71xx/files/arch/mips/ath79/mach-wnr2000-v3.c
parenteec0bac5da5228e16989c805e3bf1d166212f66f (diff)
downloadmaster-187ad058-778627987088ee195186fbe143b5034ab7350a17.tar.gz
master-187ad058-778627987088ee195186fbe143b5034ab7350a17.tar.bz2
master-187ad058-778627987088ee195186fbe143b5034ab7350a17.zip
ar71xx: add support for Netgear WPN824N
Add support for Netgear WPN824N. Hardware specs: * AR7240, 4 LAN ports, 1 WAN port * AR9285 WLAN * 32 MB RAM * 4 MB Flash * 16 LEDs (LAN, WAN and Power/Status contain two LEDs for dual color effect) * 3 Buttons (not supported) Signed-off-by: Hartmut Knaack <knaack.h@gmx.de> git-svn-id: svn://svn.openwrt.org/openwrt/trunk@48356 3c298f89-4303-0410-b956-a3cf2f4a3e73
Diffstat (limited to 'target/linux/ar71xx/files/arch/mips/ath79/mach-wnr2000-v3.c')
-rw-r--r--target/linux/ar71xx/files/arch/mips/ath79/mach-wnr2000-v3.c124
1 files changed, 122 insertions, 2 deletions
diff --git a/target/linux/ar71xx/files/arch/mips/ath79/mach-wnr2000-v3.c b/target/linux/ar71xx/files/arch/mips/ath79/mach-wnr2000-v3.c
index 2e14782200..205c2e7d5a 100644
--- a/target/linux/ar71xx/files/arch/mips/ath79/mach-wnr2000-v3.c
+++ b/target/linux/ar71xx/files/arch/mips/ath79/mach-wnr2000-v3.c
@@ -1,7 +1,8 @@
/*
* NETGEAR WNR2000v3/WNR612v2/WNR1000v2 board support
*
- * Copytight (C) 2013 Mathieu Olivari <mathieu.olivari@gmail.com>
+ * Copyright (C) 2015 Hartmut Knaack <knaack.h@gmx.de>
+ * Copyright (C) 2013 Mathieu Olivari <mathieu.olivari@gmail.com>
* Copyright (C) 2008-2009 Gabor Juhos <juhosg@openwrt.org>
* Copyright (C) 2008 Imre Kaloz <kaloz@openwrt.org>
* Copyright (C) 2008-2009 Andy Boyett <agb@openwrt.org>
@@ -15,6 +16,8 @@
#include <linux/mtd/partitions.h>
#include <asm/mach-ath79/ath79.h>
+#include <asm/mach-ath79/ar71xx_regs.h> /* needed to disable switch LEDs */
+#include "common.h" /* needed to disable switch LEDs */
#include "dev-ap9x-pci.h"
#include "dev-eth.h"
@@ -34,6 +37,29 @@
#define WNR1000V2_GPIO_LED_PWR_AMBER 1
#define WNR1000V2_GPIO_LED_PWR_GREEN 11
+/* Connected through AR7240 */
+#define WPN824N_GPIO_LED_WAN_AMBER 0
+#define WPN824N_GPIO_LED_STATUS_AMBER 1
+#define WPN824N_GPIO_LED_LAN1_AMBER 6 /* AR724X_GPIO_FUNC_JTAG_DISABLE */
+#define WPN824N_GPIO_LED_LAN2_AMBER 7 /* AR724X_GPIO_FUNC_JTAG_DISABLE */
+#define WPN824N_GPIO_LED_LAN3_AMBER 8 /* AR724X_GPIO_FUNC_JTAG_DISABLE */
+#define WPN824N_GPIO_LED_LAN4_AMBER 12
+#define WPN824N_GPIO_LED_LAN1_GREEN 13
+#define WPN824N_GPIO_LED_LAN2_GREEN 14
+#define WPN824N_GPIO_LED_LAN3_GREEN 15 /* AR724X_GPIO_FUNC_CLK_OBS3_EN */
+#define WPN824N_GPIO_LED_LAN4_GREEN 16
+#define WPN824N_GPIO_LED_WAN_GREEN 17
+
+/* Connected through AR9285 */
+#define WPN824N_WGPIO_LED_PWR_GREEN 0
+#define WPN824N_WGPIO_LED_WLAN_BLUE 1
+#define WPN824N_WGPIO_LED_WPS1_BLUE 5
+#define WPN824N_WGPIO_LED_WPS2_BLUE 9
+#define WPN824N_WGPIO_LED_TEST_AMBER 10
+#define WPN824N_WGPIO_BTN_PUSH 6 /* currently unused */
+#define WPN824N_WGPIO_BTN_RESET 7 /* currently unused */
+#define WPN824N_WGPIO_BTN_WLAN 8 /* currently unused */
+
#define WNR2000V3_KEYS_POLL_INTERVAL 20 /* msecs */
#define WNR2000V3_KEYS_DEBOUNCE_INTERVAL (3 * WNR2000V3_KEYS_POLL_INTERVAL)
@@ -73,6 +99,78 @@ static struct gpio_led wnr1000v2_leds_gpio[] __initdata = {
}
};
+static struct gpio_led wpn824n_leds_gpio[] __initdata = {
+ {
+ .name = "netgear:amber:wan",
+ .gpio = WPN824N_GPIO_LED_WAN_AMBER,
+ .active_low = 1,
+ }, {
+ .name = "netgear:amber:status",
+ .gpio = WPN824N_GPIO_LED_STATUS_AMBER,
+ .active_low = 1,
+ }, {
+ .name = "netgear:amber:lan1",
+ .gpio = WPN824N_GPIO_LED_LAN1_AMBER,
+ .active_low = 1,
+ }, {
+ .name = "netgear:amber:lan2",
+ .gpio = WPN824N_GPIO_LED_LAN2_AMBER,
+ .active_low = 1,
+ }, {
+ .name = "netgear:amber:lan3",
+ .gpio = WPN824N_GPIO_LED_LAN3_AMBER,
+ .active_low = 1,
+ }, {
+ .name = "netgear:amber:lan4",
+ .gpio = WPN824N_GPIO_LED_LAN4_AMBER,
+ .active_low = 1,
+ }, {
+ .name = "netgear:green:lan1",
+ .gpio = WPN824N_GPIO_LED_LAN1_GREEN,
+ .active_low = 1,
+ }, {
+ .name = "netgear:green:lan2",
+ .gpio = WPN824N_GPIO_LED_LAN2_GREEN,
+ .active_low = 1,
+ }, {
+ .name = "netgear:green:lan3",
+ .gpio = WPN824N_GPIO_LED_LAN3_GREEN,
+ .active_low = 1,
+ }, {
+ .name = "netgear:green:lan4",
+ .gpio = WPN824N_GPIO_LED_LAN4_GREEN,
+ .active_low = 1,
+ }, {
+ .name = "netgear:green:wan",
+ .gpio = WPN824N_GPIO_LED_WAN_GREEN,
+ .active_low = 1,
+ }
+};
+
+static struct gpio_led wpn824n_wmac_leds_gpio[] = {
+ {
+ .name = "netgear:green:power",
+ .gpio = WPN824N_WGPIO_LED_PWR_GREEN,
+ .active_low = 1,
+ }, {
+ .name = "netgear:blue:wlan",
+ .gpio = WPN824N_WGPIO_LED_WLAN_BLUE,
+ .active_low = 1,
+ }, {
+ .name = "netgear:blue:wps1",
+ .gpio = WPN824N_WGPIO_LED_WPS1_BLUE,
+ .active_low = 1,
+ }, {
+ .name = "netgear:blue:wps2",
+ .gpio = WPN824N_WGPIO_LED_WPS2_BLUE,
+ .active_low = 1,
+ }, {
+ .name = "netgear:amber:test",
+ .gpio = WPN824N_WGPIO_LED_TEST_AMBER,
+ .active_low = 1,
+ }
+};
+
static struct gpio_keys_button wnr2000v3_gpio_keys[] __initdata = {
{
.desc = "wps",
@@ -138,3 +236,25 @@ static void __init wnr1000v2_setup(void)
}
MIPS_MACHINE(ATH79_MACH_WNR1000_V2, "WNR1000V2", "NETGEAR WNR1000 V2", wnr1000v2_setup);
+
+static void __init wpn824n_setup(void)
+{
+ ath79_gpio_function_setup(AR724X_GPIO_FUNC_JTAG_DISABLE,
+ AR724X_GPIO_FUNC_ETH_SWITCH_LED0_EN |
+ AR724X_GPIO_FUNC_ETH_SWITCH_LED1_EN |
+ AR724X_GPIO_FUNC_ETH_SWITCH_LED2_EN |
+ AR724X_GPIO_FUNC_ETH_SWITCH_LED3_EN |
+ AR724X_GPIO_FUNC_ETH_SWITCH_LED4_EN |
+ AR724X_GPIO_FUNC_CLK_OBS3_EN);
+
+ wnr_common_setup();
+
+ ath79_register_leds_gpio(-1, ARRAY_SIZE(wpn824n_leds_gpio),
+ wpn824n_leds_gpio);
+
+ ap9x_pci_setup_wmac_led_pin(0, WPN824N_WGPIO_LED_WLAN_BLUE);
+ ap9x_pci_setup_wmac_leds(0, wpn824n_wmac_leds_gpio,
+ ARRAY_SIZE(wpn824n_wmac_leds_gpio));
+}
+
+MIPS_MACHINE(ATH79_MACH_WPN824N, "WPN824N", "NETGEAR WPN824N", wpn824n_setup);
@@ -1,7 +1,8 @@
/*
- * NETGEAR WNR2000v3/WNR612v2/WNR1000v2 board support
+ * NETGEAR WNR2000v3/WNR612v2/WNR1000v2/WPN824N board support
*